==> pdfadd_2.0.orig.tar.gz: pdfadd-2.0/histodialog.h <==
/***************************************************************************
 *   copyright       : (C) 2012-2014 by Pascal Brachet                     *
 *   http://www.xm1math.net/pdfadd/                                        *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef HISTODIALOG_H
#define HISTODIALOG_H

#include "ui_histodialog.h"
#include "highlighter.h"
#include "pdfviewer.h"

#include <QProcess>
#include <QPointer>
#include <QCloseEvent>
#include <QProgressDialog>

class HistoDialog : public QDialog  {
   Q_OBJECT
public:
	HistoDialog(QWidget *parent=0);
	~HistoDialog();
	Ui::HistoDialog ui;
QString pdflatexCommande, asyCommande, lecteurpdfCommande, dernierRepertoire, nomFichier, preambuleAsy;
QColor couleurSupp1,couleurSupp2,couleurSupp3;
private :
QStringList expressionList, couleurList, styleList;
QString tempDir,asyTempFile,pdfTempFile,prefixFile;
QString asyMessage;
QPointer<QProcess> asy_pdf_proc;
bool estModifie, existvaleur, erreurProcessus;
Highlighter *highlighterSupp;
QPointer<PdfViewer> pdfviewerWindow;
QPointer<QProgressDialog> progressDialog;
public slots:
void Ouvrir(QString nouveauFichier);
private slots:
void closeEvent(QCloseEvent *e);
void accept();
void reject();
void Init();
void ActiverRectangles(bool etat);
void ActiverAxes(bool etat);
void ActiverGrille(bool etat);
bool Operateur(QString mot);
bool Fonction(QString mot);
int Priorite(QString mot);
QString CalculOp(QString n,QString m,QString x,QString variable);
QString CalculAp(QString n,QString x,QString variable);
QString CalculerExpression(QString expression, QString variable);
QString CalculerExpressionArrondi(QString expression, QString variable);
QString GenererCode();
void AfficherCode();
void ajouterRectangle();
void supprimerRectangle();
void actualiserExpression();
void actualiserCouleur();
void actualiserStyle();
void actualiserItemInfo();
int numeroItem();
void NouvelHistogramme();
void SauverHistogramme();
void ChargerHistogramme();

void AsyPdfTemp();
void finAsyPdfProcess(int err);
void VoirTemp();
void readInfoOutput();

void NettoyerCode();

void Aide();

void ExporterPdf();
void ExporterPdfSuite();
void CopierFichier(QString origine,QString destination);
signals:
void asy_pdf_fini();
};


#endif

==> pdfadd_2.0.1.orig.tar.gz: pdfadd-2.0.1/histodialog.h <==
/***************************************************************************
 *   copyright       : (C) 2012-2021 by Pascal Brachet                     *
 *   https://www.xm1math.net/pdfadd/                                       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   @license GPL-2.0+ <https://spdx.org/licenses/GPL-2.0+.html>           *
 ***************************************************************************/

#ifndef HISTODIALOG_H
#define HISTODIALOG_H

#include "ui_histodialog.h"
#include "highlighter.h"
#include "pdfviewer.h"
#include "cmdlauncher.h"


#include <QPointer>
#include <QCloseEvent>


class HistoDialog : public QDialog  {
   Q_OBJECT
public:
	HistoDialog(QWidget *parent=0);
	~HistoDialog();
	Ui::HistoDialog ui;
QString extraPath, pdflatexCommande, asyCommande, lecteurpdfCommande, dernierRepertoire, nomFichier, preambuleAsy;
QColor couleurSupp1,couleurSupp2,couleurSupp3;
private :
QStringList expressionList, couleurList, styleList;
QString tempDir,asyTempFile,pdfTempFile,prefixFile;
QPointer<CmdLauncher> asy_pdf_proc;
bool estModifie, existvaleur, erreurProcessus;
Highlighter *highlighterSupp;
QPointer<PdfViewer> pdfviewerWindow;
public slots:
void Ouvrir(QString nouveauFichier);
private slots:
void closeEvent(QCloseEvent *e);
void accept();
void reject();
void Init();
void ActiverRectangles(bool etat);
void ActiverAxes(bool etat);
void ActiverGrille(bool etat);
bool Operateur(QString mot);
bool Fonction(QString mot);
int Priorite(QString mot);
QString CalculOp(QString n,QString m,QString x,QString variable);
QString CalculAp(QString n,QString x,QString variable);
QString CalculerExpression(QString expression, QString variable);
QString CalculerExpressionArrondi(QString expression, QString variable);
QString GenererCode();
void AfficherCode();
void ajouterRectangle();
void supprimerRectangle();
void actualiserExpression();
void actualiserCouleur();
void actualiserStyle();
void actualiserItemInfo();
int numeroItem();
void NouvelHistogramme();
void SauverHistogramme();
void ChargerHistogramme();

void AsyPdfTemp();
void VoirTemp();
void ErreurCompilation();

void NettoyerCode();

void Aide();

void ExporterPdf();
void ExporterPdfSuite();
void CopierFichier(QString origine,QString destination);
signals:
void asy_pdf_fini();
};


#endif
